@@ -53,8 +53,8 @@
   (let ((fm-index (hz->radians (* index mc-ratio freq))))
     (let ((start (seconds->samples beg))
 	  (end (seconds->samples (+ beg dur)))
-	  (cr (make-oscil freq))                     ; our carrier
-	  (md (make-oscil (* freq mc-ratio)))        ; our modulator
+	  (cr (make-oscil freq))                     ; carrier
+	  (md (make-oscil (* freq mc-ratio)))        ; modulator
 	  (ampf (make-env (or amp-env '(0 0 .5 1 1 0)) :scaler amp :duration dur))
 	  (indf (make-env (or index-env '(0 0 .5 1 1 0)) :scaler fm-index :duration dur)))
       (do ((i start (+ i 1)))
@@ -536,10 +536,10 @@
       (outa i (* amp (in-any ctr 0 fil))))))
 
 (define (simple-in-rev beg dur ampa ampb)
-  (let ((start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur)))
-	(chns (mus-channels *reverb*)))
-    (if (or (> ampa 0.0) (> ampb 0.0))
+  (if (or (> ampa 0.0) (> ampb 0.0))
+      (let ((start (seconds->samples beg))
+	    (end (seconds->samples (+ beg dur)))
+	    (chns (mus-channels *reverb*)))
 	(if (or (zero? ampb) (= chns 1))
 	    (do ((i start (+ i 1))) ((= i end))
 	      (outa i (* ampa (ina i *reverb*))))
@@ -1199,11 +1199,14 @@
   (let ((start (seconds->samples beg))
 	(end (seconds->samples (+ beg dur)))
 	(cr (make-oscil freq carrier-phase))
-	(n (length mc-ratios)))
-    (define (interleave a b)
-      (let ((lst ()))
-	(for-each (lambda (x y) (set! lst (cons (hz->radians (* freq x y)) (cons x lst)))) a b)
-	(reverse lst)))
+	(n (length mc-ratios))
+	(interleave (lambda (a b)
+		      (let ((lst ()))
+			(for-each (lambda (x y) 
+				    (set! lst (cons (hz->radians (* freq x y))
+						    (cons x lst))))
+				  a b)
+			(reverse lst)))))
     (if (and (apply and (map integer? mc-ratios))
 	     (apply and (map zero? mod-phases))) ; use polyoid if any not 0.0
 	(let ((fm (make-polywave freq (interleave mc-ratios indexes) mus-chebyshev-second-kind)))
@@ -1417,18 +1420,6 @@
 	((= i end))
       (outa i (* amp (oscil os (env frqe)))))))
 
-(definstrument (sndclmdoc-simple-fm beg dur freq amp mc-ratio index amp-env index-env)
-  (let ((fm-index (hz->radians (* index mc-ratio freq))))
-    (let ((start (seconds->samples beg))
-	  (end (seconds->samples (+ beg dur)))
-	  (cr (make-oscil freq))                     ; carrier
-	  (md (make-oscil (* freq mc-ratio)))        ; modulator
-	  (ampf (make-env (or amp-env '(0 0  .5 1  1 0)) :scaler amp :duration dur))
-	  (indf (make-env (or index-env '(0 0  .5 1  1 0)) :scaler fm-index :duration dur)))
-      (do ((i start (+ i 1)))
-	  ((= i end))
-	(outa i (* (env ampf) (oscil cr (* (env indf) (oscil md)))))))))
-
 (define (sndclmdoc-simple-add beg dur freq amp)
   (let ((start (seconds->samples beg))
 	(end (seconds->samples (+ beg dur)))
@@ -2015,7 +2006,7 @@
   freq phase (ratio 1.0) (r 1.0) (index 1.0) input r1 r2 r3)
 
 (define dsp-asyfm-J 
-  (let ((documentation "(dsp-asyfm-J gen input) is the same as the CLM asymmetric-fm generator, set r != 1.0 to get the asymmetric spectra"))
+  (let ((+documentation+ "(dsp-asyfm-J gen input) is the same as the CLM asymmetric-fm generator, set r != 1.0 to get the asymmetric spectra"))
     (lambda (gen input)
       (let-set! gen 'input input)
       (with-let gen
@@ -2026,7 +2017,7 @@
 	  result)))))
 
 (define dsp-asyfm-I 
-  (let ((documentation "(dsp-asyfm-I gen input) is the I0 case of the asymmetric-fm generator (dsp.scm)"))
+  (let ((+documentation+ "(dsp-asyfm-I gen input) is the I0 case of the asymmetric-fm generator (dsp.scm)"))
     (lambda (gen input)
       (let-set! gen 'input input)
       (with-let gen
@@ -2114,7 +2105,7 @@
 	(outa i (my-oscil osc 0.0)))))
   (with-sound () 
     (sndclmdoc-simp-5 0 10000 440 .1 '(0 0 1 1)) ; sweep up an octave
-    (sndclmdoc-simple-fm 1 1 440 .1 2 1.0)
+    (simple-fm 1 1 440 .1 2 1.0)
     (sndclmdoc-simple-add 2 1 220 .3)
     (sndclmdoc-mapenv 3 1 440 .4 '(0 0 50 1 75 0 86 .5 100 0)))
   (if (file-exists? "/home/bil/sf1/forest.aiff")
@@ -2194,10 +2185,8 @@
   (with-sound (:channels 4) (sndclmdoc-simple-dloc 0 2 440 .5))
   (with-sound () (when? 0 4 2.0 8.0 "1a.snd"))
   (with-sound () (move-formants 0 "oboe.snd" 2.0 0.99 '(0 1200 1.6 2400 2 1400) 4))
-  (test-filter (make-one-zero 0.5 0.5))
-  (test-filter (make-one-pole 0.1 -0.9))
-  (test-filter (make-two-pole 0.1 0.1 0.9))
-  (test-filter (make-two-zero 0.5 0.2 0.3))
+
+  (for-each test-filter (vector (make-one-zero 0.5 0.5) (make-one-pole 0.1 -0.9) (make-two-pole 0.1 0.1 0.9) (make-two-zero 0.5 0.2 0.3)))
   
   (with-sound (:scaled-to .5) ; .875
     (flux 0 "oboe.snd" 10.0 '(1.0 1.25 1.5) '(1.0 1.333 1.6))
