@@ -88,12 +88,6 @@
 ;;; 	        (char* read_dir (DIR*)))
 ;;;   "" '("sys/types.h" "dirent.h"))
 ;;; 
-;;; (let ((dir (opendir "/home/bil/gtk-snd")))
-;;;   (do ((p (read_dir dir) (read_dir dir)))
-;;;       ((= (length p) 0))
-;;;     (format *stderr* "~A " p))
-;;;   (closedir dir))
-;;;
 ;;; (define (memory-usage)
 ;;;   (with-let *libc*
 ;;;     (let ((v (rusage.make))) 
@@ -144,7 +138,7 @@
 
   (define (C-type->s7-type type)
 
-    (if (pair? type)                             ; in case the type name does not make its C type obvious: (graph_style_t int)
+    (if (pair? type)                                  ; in case the type name does not make its C type obvious: (graph_style_t int)
 	(C-type->s7-type (cadr type))
 	(let ((type-name (symbol->string type)))
 	  (cond ((string-position "**" type-name)     ; any complicated C pointer is uninterpreted
@@ -289,19 +283,31 @@
 	(format p "#include \"s7.h\"~%~%"))
       
       (define collides?
-	(let ((all-names ()))
+	(let ((all-names (hash-table)))
 	  (lambda (name)
-	    (if (memq name all-names) 
+	    (if (hash-table-ref all-names name) 
 		(format *stderr* "~A twice?~%" name)
-		(set! all-names (cons name all-names)))
+		(hash-table-set! all-names name #t))
 	    name)))
+
+      (define (hyphen->space type)
+	(let* ((name (symbol->string type))
+	       (pos (char-position #\- name)))
+	  (if (not pos)
+	      type
+	      (begin
+		(string-set! name pos #\space)
+		(set! pos (char-position #\- name (+ pos 1)))
+		(if pos
+		    (string-set! name pos #\space))
+		name))))
       
       (define* (add-one-function return-type name arg-types doc)
 	;; (format *stderr* "~A ~A ~A~%" return-type name arg-types): double j0 (double) for example
 	;; C function -> scheme
 	(let ((func-name (symbol->string (collides? name))))
 	  (let ((num-args (length arg-types))
-		(base-name (string-append (if (> (length prefix) 0) prefix "s7_dl") "_" func-name)) ; not "g" -- collides with glib
+		(base-name (string-append (if (> (length prefix) 0) prefix "s7_") "_" func-name)) ; not "g" -- collides with glib
 		(scheme-name (string-append prefix (if (> (length prefix) 0) ":" "") func-name)))
 	  
 	    (if (and (= num-args 1) 
@@ -317,7 +323,7 @@
 	      (do ((i 0 (+ i 1))
 		   (type arg-types (cdr type)))
 		  ((= i num-args))
-		(format p "  ~A ~A_~D;~%" ((if (pair? (car type)) caar car) type) base-name i))
+		(format p "  ~A ~A_~D;~%" (hyphen->space ((if (pair? (car type)) caar car) type)) base-name i))
 	      (if (not (= num-args 1)) (format p "  arg = args;~%"))
 	      (do ((i 0 (+ i 1))
 		   (type arg-types (cdr type)))
@@ -326,25 +332,24 @@
 		(let* ((nominal-type ((if (pair? (car type)) caar car) type))  ; double in the example
 		       (true-type    ((if (pair? (car type)) cadar car) type))
 		       (s7-type      (C-type->s7-type true-type)))                    ; real
-		  ;(format *stderr* "~A(~D): ~A ~A ~A~%" func-name i nominal-type true-type s7-type)
+
 		  (if (eq? true-type 's7_pointer)
 		      (format p "    ~A_~D = s7_car(arg);~%" base-name i)
 		      (if (eq? s7-type 'c_pointer)
-			  (begin
-			    (format p "  if (s7_is_c_pointer_of_type(s7_car(arg), s7_make_symbol(sc, ~S)))~%" (symbol->string nominal-type))
-			    (format p "    ~A_~D = (~A)s7_c_pointer(s7_car(arg));~%" base-name i nominal-type)
-			    (format p "  else return(s7_wrong_type_arg_error(sc, ~S, ~D, s7_car(arg), ~S));~%"
-				func-name (if (= num-args 1) 0 (+ i 1)) (symbol->string nominal-type)))
+			  (format p "  ~A_~D = (~A)s7_c_pointer_with_type(sc, s7_car(arg), s7_make_symbol(sc, ~S), __func__, ~S);~%" 
+				  base-name i 
+				  (hyphen->space nominal-type)
+				  (symbol->string nominal-type)
+				  (if (= num-args 1) 0 (+ i 1)))
 			  (begin
 			    (format p "  if (~A(s7_car(arg)))~%" (checker true-type))
 			    (format p "    ~A_~D = (~A)~A(~As7_car(arg));~%"
 				    base-name i
-				    nominal-type
+				    (hyphen->space nominal-type)
 				    (s7->C true-type)                               ; s7_number_to_real which requires 
 				    (if (memq s7-type '(boolean real))              ;   the extra sc arg
 					"sc, " ""))
-			    (format p "  else return(s7_wrong_type_arg_error(sc, ~S, ~D, s7_car(arg), ~S));~%"
-				    func-name 
+			    (format p "  else return(s7_wrong_type_arg_error(sc, __func__, ~D, s7_car(arg), ~S));~%"
 				    (if (= num-args 1) 0 (+ i 1))
 				    (if (symbol? s7-type) 
 					(symbol->string s7-type) 
@@ -496,7 +501,7 @@
 	   (format p "  ~A~%" init-str))
 	 (reverse inits))
 	
-	;; "constants" -- actually variables in s7 because we want them to be local to the current environment (this comment is obsolete)
+	;; constants
 	(if (pair? constants)
 	    (begin
 	      (format p "~%")
@@ -570,7 +575,7 @@
 	  (for-each
 	   (lambda (f)
 	     (unless (defined? (symbol (cadr f)) (rootlet))
-	       (format p "  s7_set~A_function(s7_name_to_value(sc, ~S), ~A~A);~%" (caddr f) (cadr f) (car f) (caddr f))))
+	       (format p "  s7_set~A_function(sc, s7_name_to_value(sc, ~S), ~A~A);~%" (caddr f) (cadr f) (car f) (caddr f))))
 	   double-funcs))
 	
 	(when (pair? int-funcs)
@@ -578,11 +583,15 @@
 	  (for-each
 	   (lambda (f)
 	     (unless (defined? (symbol (cadr f)) (rootlet))
-	       (format p "  s7_set~A_function(s7_name_to_value(sc, ~S), ~A~A);~%" (caddr f) (cadr f) (car f) (caddr f))))
+	       (format p "  s7_set~A_function(sc, s7_name_to_value(sc, ~S), ~A~A);~%" (caddr f) (cadr f) (car f) (caddr f))))
 	   int-funcs))
 	
 	(format p "}~%")
 	(close-output-port p)
+
+	(unless (or (file-exists? "s7.h")
+		    (not (pair? *load-path*)))
+	  (set! *cload-cflags* (append *cload-cflags* (format #f " -I~A" (car *load-path*)))))
 	
 	;; now we have the module .c file -- make it into a shared object, load it, delete the temp files
 	
