@@ -56,58 +56,56 @@
 	    (sr (/ 1.0 (srate snd)))
 	    (old-color (foreground-color snd chn))
 	    (axinf (axis-info snd chn))
-	    (old-axinf (channel-property 'rms-axis-info snd chn))
-	    (cr (and (provided? 'gtk4) ((channel-widgets snd chn) 17))))
-	
-	(when cr
-	  (if (equal? axinf old-axinf)                    ; the previously calculated lines can be re-used
-	      (begin
-		(set! (foreground-color snd chn) red)
-		(draw-lines (channel-property 'rms-lines snd chn) snd chn time-graph cr)
-		(set! (foreground-color snd chn) old-color))
-	      (let ((start (max 0 (- left rms-size))))
-		(let ((xdata (pack-x-info axinf))
-		      (ydata (pack-y-info axinf))
-		      (reader (make-sampler start snd chn))
-		      (rms (make-moving-rms rms-size))
-		      (x0 0)
-		      (y0 0)
-		      (line-ctr 2)
-		      (lines (make-vector (* 2 (- (+ (axinf 12) 1) (axinf 10))) 0)))
-		  (dynamic-wind
-		      (lambda ()
-			(set! (foreground-color snd chn) red))
-		      (lambda ()
-			(if (< start left)                 ; check previous samples to get first rms value
-			    (do ((i start (+ 1 i))) 
-				((= i left))
-			      (moving-rms rms (reader))))
-			(let ((first-sample (next-sample reader)))
-			  (set! x0 (grf-it (* left sr) xdata))
-			  (set! y0 (grf-it first-sample ydata)))
-			(set! (lines 0) x0)                ; first graph point
-			(set! (lines 1) y0)
-			(do ((i (+ left 1) (+ 1 i)))       ; loop through all samples calling moving-rms
-			    ((= i right))
-			  (let ((x1 (grf-it (* i sr) xdata))
-				(y (moving-rms rms (next-sample reader))))
-			    (if (> x1 x0)                 ; very often many samples are represented by one pixel
-				(let ((y1 (grf-it y ydata)))
-				  (set! (lines line-ctr) x1)
-				  (set! (lines (+ 1 line-ctr)) y1)
-				  (set! line-ctr (+ line-ctr 2))
-				  (set! x0 x1)
-				  (set! y0 y1)))))      ; else should we do "max" here? or draw a vertical line from min to max?
-			(if (< line-ctr (length lines))
-			    (do ((j line-ctr (+ j 2)))       ; off-by-one in vector size calc -- need to pad so we don't get a bogus line to (0, 0)
-				((>= j (length lines)))
-			      (set! (lines j) x0)
-			      (set! (lines (+ j 1)) y0)))
-			(draw-lines lines snd chn time-graph cr)
-			(set! (channel-property 'rms-lines snd chn) lines)  ; save current data for possible redisplay
-			(set! (channel-property 'rms-axis-info snd chn) axinf))
-		      (lambda ()
-			(set! (foreground-color snd chn) old-color)))))))))))
+	    (old-axinf (channel-property 'rms-axis-info snd chn)))
+
+	(if (equal? axinf old-axinf)                    ; the previously calculated lines can be re-used
+	    (begin
+	      (set! (foreground-color snd chn) red)
+	      (draw-lines (channel-property 'rms-lines snd chn) snd chn time-graph #f)
+	      (set! (foreground-color snd chn) old-color))
+	    (let ((start (max 0 (- left rms-size))))
+	      (let ((xdata (pack-x-info axinf))
+		    (ydata (pack-y-info axinf))
+		    (reader (make-sampler start snd chn))
+		    (rms (make-moving-rms rms-size))
+		    (x0 0)
+		    (y0 0)
+		    (line-ctr 2)
+		    (lines (make-vector (* 2 (- (+ (axinf 12) 1) (axinf 10))) 0)))
+		(dynamic-wind
+		    (lambda ()
+		      (set! (foreground-color snd chn) red))
+		    (lambda ()
+		      (if (< start left)                 ; check previous samples to get first rms value
+			  (do ((i start (+ 1 i))) 
+			      ((= i left))
+			    (moving-rms rms (reader))))
+		      (let ((first-sample (next-sample reader)))
+			(set! x0 (grf-it (* left sr) xdata))
+			(set! y0 (grf-it first-sample ydata)))
+		      (set! (lines 0) x0)                ; first graph point
+		      (set! (lines 1) y0)
+		      (do ((i (+ left 1) (+ 1 i)))       ; loop through all samples calling moving-rms
+			  ((= i right))
+			(let ((x1 (grf-it (* i sr) xdata))
+			      (y (moving-rms rms (next-sample reader))))
+			  (if (> x1 x0)                 ; very often many samples are represented by one pixel
+			      (let ((y1 (grf-it y ydata)))
+				(set! (lines line-ctr) x1)
+				(set! (lines (+ 1 line-ctr)) y1)
+				(set! line-ctr (+ line-ctr 2))
+				(set! x0 x1)
+				(set! y0 y1)))))      ; else should we do "max" here? or draw a vertical line from min to max?
+		      (if (< line-ctr (length lines))
+			  (do ((j line-ctr (+ j 2)))       ; off-by-one in vector size calc -- need to pad so we don't get a bogus line to (0, 0)
+			      ((>= j (length lines)))
+			    (set! (lines j) x0)
+			    (set! (lines (+ j 1)) y0)))
+		      (draw-lines lines snd chn time-graph #f)
+		      (set! (channel-property 'rms-lines snd chn) lines)  ; save current data for possible redisplay
+		      (set! (channel-property 'rms-axis-info snd chn) axinf))
+		    (lambda ()
+		      (set! (foreground-color snd chn) old-color))))))))))
     
 ;; (hook-push after-graph-hook (lambda (hook) (overlay-rms-env (hook 'snd) (hook 'chn))))
 
@@ -119,10 +117,8 @@ whenever they're in the current view."))
       (let ((left (left-sample snd chn))
 	    (right (right-sample snd chn))
 	    (end (+ beg dur))
-	    (old-color (foreground-color snd chn))
-	    (cr (and (provided? 'gtk4) ((channel-widgets snd chn) 17))))
-	(when (and cr
-		   (< left end)
+	    (old-color (foreground-color snd chn)))
+	(when (and (< left end)
 		   (> right beg))
 	  (let ((data (make-graph-data snd chn)))
 	    (if (float-vector? data)
@@ -130,7 +126,7 @@ whenever they're in the current view."))
 				      (offset (max 0 (- beg left))))
 				  (float-vector-subseq data offset (+ offset samps)))))
 		  (set! (foreground-color snd chn) color)
-		  (graph-data new-data snd chn copy-context (max beg left) (min end right) (time-graph-style snd chn) cr)
+		  (graph-data new-data snd chn copy-context (max beg left) (min end right) (time-graph-style snd chn) #f)
 		  (set! (foreground-color snd chn) old-color))
 		(let* ((size (length (car data)))
 		       (samps (- right left))
@@ -139,7 +135,7 @@ whenever they're in the current view."))
 		       (new-low-data (float-vector-subseq (car data) left-bin right-bin))
 		       (new-high-data (float-vector-subseq (cadr data) left-bin right-bin)))
 		  (set! (foreground-color snd chn) color)
-		  (graph-data (list new-low-data new-high-data) snd chn copy-context left-bin right-bin (time-graph-style snd chn) cr)
+		  (graph-data (list new-low-data new-high-data) snd chn copy-context left-bin right-bin (time-graph-style snd chn) #f)
 		  (set! (foreground-color snd chn) old-color)))))))))
 
 
@@ -188,18 +184,16 @@ whenever they're in the current view."))
 		 (clist (color->list old-color)))
 	    (let ((rinc (/ (- 1.0 (car clist)) (+ edits 1)))
 		  (ginc (/ (- 1.0 (cadr clist)) (+ edits 1)))
-		  (binc (/ (- 1.0 (caddr clist)) (+ edits 1)))
-		  (cr (and (provided? 'gtk4) ((channel-widgets snd chn) 17))))
-	      (when cr
-		(do ((pos 0 (+ 1 pos))
-		     (re (- 1.0 rinc) (- re rinc))
-		     (ge (- 1.0 ginc) (- ge ginc))
-		     (be (- 1.0 binc) (- be binc)))
-		    ((> pos edits))
-		  (let ((data (make-graph-data snd chn pos)))
-		    (set! (foreground-color snd chn) (make-color re ge be))
-		    (graph-data data snd chn copy-context #f #f (time-graph-style snd chn) cr)))
-		(set! (foreground-color snd chn) old-color)))))))))
+		  (binc (/ (- 1.0 (caddr clist)) (+ edits 1))))
+	      (do ((pos 0 (+ 1 pos))
+		   (re (- 1.0 rinc) (- re rinc))
+		   (ge (- 1.0 ginc) (- ge ginc))
+		   (be (- 1.0 binc) (- be binc)))
+		  ((> pos edits))
+		(let ((data (make-graph-data snd chn pos)))
+		  (set! (foreground-color snd chn) (make-color re ge be))
+		  (graph-data data snd chn copy-context #f #f (time-graph-style snd chn) #f)))
+	      (set! (foreground-color snd chn) old-color))))))))
 
 (define overlay-sounds
   (let ((+documentation+ "(overlay-sounds . args) overlays onto its first argument all subsequent arguments: (overlay-sounds 1 0 3)"))
@@ -212,22 +206,18 @@ whenever they're in the current view."))
 		     (let ((snd (hook 'snd))
 			   (chn (hook 'chn)))
 		       (if (equal? snd base)
-			   (let ((cr (and (provided? 'gtk4) ((channel-widgets snd chn) 17))))
-			     (when cr
-			       (for-each 
-				(lambda (nsnd)
-				  (if (and (sound? nsnd)
-					   (> (chans nsnd) chn))
-				      (graph-data (make-graph-data nsnd chn) base chn copy-context #f #f graph-dots cr)))
-				(cdr args))))))))))))
+			   (for-each 
+			    (lambda (nsnd)
+			      (if (and (sound? nsnd)
+				       (> (chans nsnd) chn))
+				  (graph-data (make-graph-data nsnd chn) base chn copy-context #f #f graph-dots #f)))
+			    (cdr args))))))))))
 
 
 (define samples-via-colormap 
   (let ((+documentation+ "(samples-via-colormap snd chn) displays time domain graph using current colormap (just an example of colormap-ref)"))
     (lambda (snd chn)
-      (let ((data (make-graph-data snd chn))
-	    (cr (and (provided? 'gtk4) ((channel-widgets snd chn) 17))))
-	
+      (let ((data (make-graph-data snd chn)))
 	(define (samples-1 cur-data)
 	  (let ((left (left-sample snd chn))
 		(right (right-sample snd chn))
@@ -249,12 +239,12 @@ whenever they're in the current view."))
 			  (or (colors ref)
 			      (let ((new-color (apply make-color (colormap-ref (colormap) x))))
 				(set! (colors ref) new-color)))))
-		  (draw-line x0 y0 x1 y1 snd chn time-graph cr)
+		  (draw-line x0 y0 x1 y1 snd chn time-graph #f)
 		  (set! x0 x1)
 		  (set! y0 y1)))
 	      (set! (foreground-color snd chn) old-color))))
 
-	(when (and cr data)
+	(when data
 	  (if (float-vector? data)
 	      (samples-1 data)
 	      (begin
