@@ -9,28 +9,25 @@
 
 (provide 'snd-musglyphs.scm)
 
-(define make-polygon
-  (lambda (args)
-    (define (total-length vects len)
-      (cond ((null? vects)         len)
-	    ((vector? (car vects)) (total-length (cdr vects) (+ len (length (car vects)))))
-	    ((car vects)           (total-length (cdr vects) (+ len 1)))
-	    (else                  (total-length (cdr vects) len))))
-    (let set-vals ((vects args) 
-		   (start 0) 
-		   (vals (make-vector (total-length args 0))))
-      (cond ((null? vects) vals)
-	    ((vector? (car vects))
-	     (let* ((vect (car vects))
-		    (len (length vect)))
-	       (do ((i 0 (+ 1 i)))
-		   ((= i len))
-		 (set! (vals (+ start i)) (vect i)))
-	       (set-vals (cdr vects) (+ start len) vals)))
-	    ((car vects)
-	     (set! (vals start) (car vects))
-	     (set-vals (cdr vects) (+ start 1) vals))
-	    (else (set-vals (cdr vects) start vals))))))
+(define (make-polygon args)
+  (let set-vals ((vects args)
+		 (start 0)
+		 (vals (make-vector (let total-length ((vects args) (len 0))
+				      (cond ((null? vects)         len)
+					    ((vector? (car vects)) (total-length (cdr vects) (+ len (length (car vects)))))
+					    ((car vects)           (total-length (cdr vects) (+ len 1)))
+					    (else                  (total-length (cdr vects) len)))))))
+    (cond ((null? vects) vals)
+	  ((vector? (car vects))
+	   (let ((vect (car vects)))
+	     (do ((len (length vect))
+		  (i 0 (+ 1 i)))
+		 ((= i len) (set-vals (cdr vects) (+ start len) vals))
+	       (set! (vals (+ start i)) (vect i)))))
+	  ((car vects)
+	   (set! (vals start) (car vects))
+	   (set-vals (cdr vects) (+ start 1) vals))
+	  (else (set-vals (cdr vects) start vals)))))
 
 (define (make-bezier-1 x0 y0 x1 y1 x2 y2 x3 y3 n)
   ;; creates a line-segment approximation of a bezier curve: n = number of segments
@@ -109,71 +106,30 @@
     (set! pathlist (cons v pathlist))
     #f))
 
-(if (provided? 'snd-gtk)
-    (begin
-      (define* (fill-in score :rest args)
-	(if (pair? pathlist)
-	    (let ((cr (make-cairo (car (channel-widgets ps-snd ps-chn)))))
-	      (fill-polygon
-	       (make-polygon
-		(reverse pathlist))
-	       ps-snd ps-chn ps-ax cr)
-	      (free-cairo cr)))
-	(set! pathlist ())
-	#f)
-      
-      (define (draw score arg)
-	(if (pair? pathlist)
-	    (let ((cr (make-cairo (car (channel-widgets ps-snd ps-chn)))))
-	      (draw-lines
-	       (make-polygon
-		(reverse pathlist))
-	       ps-snd ps-chn ps-ax cr)
-	      (free-cairo cr)))
-	(set! pathlist ())
-	#f)
-      
-      (define (circle score x0 y0 rad . rest)
-	(let ((cr (make-cairo (car (channel-widgets ps-snd ps-chn)))))
-	  (draw-dot (->x x0) (->y y0) 
-		    (floor (* ps-size rad 2))
-		    ps-snd ps-chn ps-ax cr)
-	  (free-cairo cr)))
+(define* (fill-in score :rest args)
+  (if (not (null? pathlist))
+      (fill-polygon
+       (make-polygon
+	(reverse pathlist))
+       ps-snd ps-chn ps-ax))
+  (set! pathlist ())
+  #f)
 
-      (define (fill-rectangle-1 . args)
-	(let ((cr (make-cairo (car (channel-widgets ps-snd ps-chn))))
-	      (new-args (copy args (make-list 9 #f))))
-	  (if (not (new-args 6))
-	      (set! (new-args 6) time-graph))
-	  (set! (new-args 8) cr)
-	  (apply fill-rectangle new-args)
-	  (free-cairo cr))))
-    (begin
-      (define* (fill-in score :rest args)
-	(if (not (null? pathlist))
-	    (fill-polygon
-	     (make-polygon
-	      (reverse pathlist))
-	     ps-snd ps-chn ps-ax))
-	(set! pathlist ())
-	#f)
-      
-      (define (draw score arg)
-	(if (not (null? pathlist))
-	    (draw-lines
-	     (make-polygon
-	      (reverse pathlist))
-	     ps-snd ps-chn ps-ax))
-	(set! pathlist ())
-	#f)
-      
-      (define (circle score x0 y0 rad . rest)
-	(draw-dot (->x x0) (->y y0) 
-		  (floor (* ps-size rad 2))
-		  ps-snd ps-chn ps-ax))
+(define (draw score arg)
+  (if (not (null? pathlist))
+      (draw-lines
+       (make-polygon
+	(reverse pathlist))
+       ps-snd ps-chn ps-ax))
+  (set! pathlist ())
+  #f)
 
-      (define fill-rectangle-1 fill-rectangle)
-      ))
+(define (circle score x0 y0 rad . rest)
+  (draw-dot (->x x0) (->y y0) 
+	    (floor (* ps-size rad 2))
+	    ps-snd ps-chn ps-ax))
+
+(define fill-rectangle-1 fill-rectangle)
 
 
 ;(define-macro (defvar name value) `(define ,name ,value))
@@ -220,37 +176,36 @@
 ;	 (apply (setter sound-comment) (list #f snd))
 ;	 (apply (setter sound-comment) (list snd val))))))
 
-;(load "loop.scm") ; Rick's loop implementation (cm/src/loop.scm)
 (define progn begin)
 
 (load "cmn-glyphs.lisp")
 
-
-
 ;;; a portion of CMN here to make it easier to display notes
 
-(define (frequency->note-octave-and-accidental freq)
-  (define (frequency->pitch freq)
-    (floor (* 12 (+ (log (/ freq 16.351) 2) (/ 1.0 24)))))
-
-  (let* ((pitch (frequency->pitch freq))
-	 (pclass (modulo pitch 12)))
-    (let ((octave (floor (/ pitch 12)))
-	  (cclass (case pclass
-		    ((0 1) 0) ; c-sharp
-		    ((2) 1) 
-		    ((3 4) 2) ; e-flat
-		    ((5 6) 3) ; f-sharp
-		    ((7) 4) 
-		    ((8 9) 5) ; a-flat
-		    (else 6)))) ; b-flat
-      (list pclass octave 
-	    (if (memv pclass '(1 6))
-		:sharp
-		(and (memv pclass '(3 8 10)) 
-		     :flat))
-	    cclass
-	    pitch))))
+(define frequency->note-octave-and-accidental
+  (let ((frequency->pitch 
+	 (lambda (freq)
+	   (floor (* 12 (+ (log (/ freq 16.351) 2) 
+			   (/ 1.0 24)))))))
+    (lambda (freq)
+      (let* ((pitch (frequency->pitch freq))
+	     (pclass (modulo pitch 12)))
+	(let ((octave (floor (/ pitch 12)))
+	      (cclass (case pclass
+			((0 1) 0)   ; c-sharp
+			((2) 1) 
+			((3 4) 2)   ; e-flat
+			((5 6) 3)   ; f-sharp
+			((7) 4) 
+			((8 9) 5)   ; a-flat
+			(else 6)))) ; b-flat
+	  (list pclass octave 
+		(if (memv pclass '(1 6))
+		    :sharp
+		    (and (memv pclass '(3 8 10)) 
+			 :flat))
+		cclass
+		pitch))))))
 
 (define note-data->pclass car)
 (define note-data->octave cadr)
@@ -258,21 +213,12 @@
 (define note-data->cclass cadddr)
 (define (note-data->pitch val) (list-ref val 4))
 
-(if (provided? 'snd-gtk)
-    (define (draw-staff x0 y0 width line-sep)
-      (let ((cr (make-cairo (car (channel-widgets ps-snd ps-chn)))))
-	(do ((line 0 (+ 1 line))
-	     (x x0) 
-	     (y y0 (+ y (floor line-sep))))
-	    ((= line 5))
-	  (draw-line x y (floor (+ x width)) y ps-snd ps-chn time-graph cr))
-	(free-cairo cr)))
-    (define (draw-staff x0 y0 width line-sep)
-      (do ((line 0 (+ 1 line))
-	   (x x0) 
-	   (y y0 (+ y (floor line-sep))))
-	  ((= line 5))
-	(draw-line x y (floor (+ x width)) y))))
+(define (draw-staff x0 y0 width line-sep)
+  (do ((line 0 (+ 1 line))
+       (x x0) 
+       (y y0 (+ y (floor line-sep))))
+      ((= line 5))
+    (draw-line x y (floor (+ x width)) y)))
 
 
 (define treble-tag-y 30)
