@@ -767,7 +767,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 		      (apply union list (cdr sequences)))))))
 
 (define cl-set-difference
-  (let ((+documentation+ "(cl-set-difference type .sequences) returns the elements in the first sequence that are not in the rest of the sequences:\n\
+  (let ((+documentation+ "(cl-set-difference type . sequences) returns the elements in the first sequence that are not in the rest of the sequences:\n\
     (cl-set-difference vector '(1 2 3) #(2 3 4) '(1 5)) -> #()"))
     (lambda (type . sequences)     ; CL: elements in A not in B's
       (if (not (and (pair? sequences)
@@ -779,7 +779,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 			(car sequences)))))))
 
 (define symmetric-difference
-  (let ((+documentation+ "(symmetric-difference type .sequences) returns the elements that are in an odd number of the sequences:\n\
+  (let ((+documentation+ "(symmetric-difference type . sequences) returns the elements that are in an odd number of the sequences:\n\
     (symmetric-difference vector '(1 2 3) #(2 3 4) '(5)) -> #(1 4 5)"))
     (lambda (type . sequences)  ; xor, elements in an odd number of sequences (logxor A B...)
       (let ((all (apply sequences->list sequences)))
@@ -1216,7 +1216,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 			      (if (not (let? p))
 				  (apply format p args)
 				  (write (apply format #f args) p))))))
-      (subvector v i)))) ; ignore extra trailing elements (i = subvector length)
+      (subvector v 0 i)))) ; ignore extra trailing elements (i = subvector length)
 
 
 
@@ -1360,7 +1360,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	(error 'out-of-range "end: ~A should be greater than start: ~A" end start))
 
     (cond ((vector? obj)
-	   (subvector obj new-len start))
+	   (subvector obj start (+ start new-len)))
 
           ((string? obj)
            (if (integer? end)
@@ -1450,12 +1450,14 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
    :print-length                  (*s7* 'print-length)
    :safety                        (*s7* 'safety)
    :debug                         (*s7* 'debug)
+   :profile                       (*s7* 'profile)
    :cpu-time                      (*s7* 'cpu-time)
    :heap-size                     (*s7* 'heap-size)
    :free-heap-size                (*s7* 'free-heap-size)
    :max-heap-size                 (*s7* 'max-heap-size)
    :max-port-data-size            (*s7* 'max-port-data-size)
    :gc-freed                      (*s7* 'gc-freed)
+   :gc-total-freed                (*s7* 'gc-total-freed)
    :gc-protected-objects          (*s7* 'gc-protected-objects)
    :gc-stats                      (*s7* 'gc-stats)
    :gc-temps-size                 (*s7* 'gc-temps-size)
@@ -1489,6 +1491,8 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
    :history-size                  (*s7* 'history-size)
    :history-enabled               (*s7* 'history-enabled)
    :history                       (*s7* 'history)
+   :openlets                      (*s7* 'openlets)
+   :version                       (*s7* 'version)
    :most-positive-fixnum          (*s7* 'most-positive-fixnum)
    :most-negative-fixnum          (*s7* 'most-negative-fixnum)))
 
@@ -1612,9 +1616,9 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	      hash-table-set! hash-table-entries cyclic-sequences call/cc call-with-current-continuation
 	      call-with-exit apply for-each map dynamic-wind values type-of
 	      catch throw error documentation signature help procedure-source
-	      setter arity aritable? not eq? eqv? equal? equivalent? s7-version
+	      setter arity aritable? not eq? eqv? equal? equivalent? 
 	      dilambda make-hook hook-functions stacktrace tree-leaves tree-memq tree-set-memq tree-cyclic? tree-count object->let
-	      pi most-positive-fixnum most-negative-fixnum nan.0 inf.0 -nan.0 -inf.0
+	      pi most-positive-fixnum most-negative-fixnum ; +nan.0 +inf.0 -nan.0 -inf.0
 	      *stderr* *stdout* *stdin*
 	      apply-values list-values
 	      quote if begin let let* letrec letrec* cond case or and do set! unless when else
@@ -1699,13 +1703,14 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 			       (reader-cond ((not (provided? 'pure-s7))
 					     ((current-output-port) *stdout*)
 					     ((current-error-port) *stderr*))))
-	       (catch #t
-		 (lambda ()
-		   (eval new-code (sublet (rootlet) (unlet))))
-		 (lambda args
-		   (format #f "error: ~A"
-			   (catch #t
-			     (lambda ()
-			       (apply format #f (cadr args)))
-			     (lambda args
-			       (copy "?"))))))))))))
+	       (let-temporarily (((*s7* 'expansions?) #f))   ; turn off read-time macro expansion
+		 (catch #t
+		   (lambda ()
+		     (eval new-code (sublet (rootlet) (unlet))))
+		   (lambda args
+		     (format #f "error: ~A"
+			     (catch #t
+			       (lambda ()
+				 (apply format #f (cadr args)))
+			       (lambda args
+				 (copy "?")))))))))))))
