@@ -20,29 +20,31 @@
 			   (positive? (length cur-word))))
 		  (set! cur-word (string-append cur-word (string c)))
 		  (begin
-		    (if (char=? c #\newline)
-			(set! cur-line (+ cur-line 1))
-			(if (and (char=? c #\*)
-				 (char=? last-c #\/))
-			    (let ((last-c1 #\null))
-			      (do ((c1 (read-char ip) (read-char ip)))
-				  ((and (char=? c1 #\/)
-					(char=? last-c1 #\*)))
-				(if (char=? c1 #\newline)
-				    (set! cur-line (+ cur-line 1)))
-				(set! last-c1 c1)))
-			    (if (and (char=? c #\")
-				     (not (char=? last-c #\')))               ; '"' 
-				(let ((last-c1 #\null)
-				      (last-c2 #\null))
-				  (do ((c1 (read-char ip) (read-char ip)))
-				      ((and (char=? c1 #\")
-					    (or (not (char=? last-c1 #\\))    ; \"
-						(char=? last-c2 #\\))))       ; \\"
-				    (if (char=? c1 #\newline)
-					(set! cur-line (+ cur-line 1)))
-				    (set! last-c2 last-c1)
-				    (set! last-c1 c1))))))
+		    (cond ((char=? c #\newline)
+			   (set! cur-line (+ cur-line 1)))
+
+			  ((and (char=? c #\*)
+				(char=? last-c #\/))
+			   (let ((last-c1 #\null))
+			     (do ((c1 (read-char ip) (read-char ip)))
+				 ((and (char=? c1 #\/)
+				       (char=? last-c1 #\*)))
+			       (if (char=? c1 #\newline)
+				   (set! cur-line (+ cur-line 1)))
+			       (set! last-c1 c1))))
+
+			  ((and (char=? c #\")
+				(not (char=? last-c #\')))               ; '"' 
+			   (let ((last-c1 #\null)
+				 (last-c2 #\null))
+			     (do ((c1 (read-char ip) (read-char ip)))
+				 ((and (char=? c1 #\")
+				       (or (not (char=? last-c1 #\\))    ; \"
+					   (char=? last-c2 #\\))))       ; \\"
+			       (if (char=? c1 #\newline)
+				   (set! cur-line (+ cur-line 1)))
+			       (set! last-c2 last-c1)
+			       (set! last-c1 c1)))))
 		    (set! last-c c)
 		    (when (positive? (length cur-word))
 		      (hash-table-set! words cur-word 
@@ -55,22 +57,25 @@
 (define (searcher)
   ;; }\n}
   (call-with-input-file "s7.c"
-    (lambda (p)
-      (let ((last1 ""))
-	(do ((this (read-line p) (read-line p))
-	     (line 0 (+ line 1)))
-	    ((eq? this #<eof>))
-	  (let ((len (length this)))
-	    (unless (or (= len 0)
-			(char=? (string-ref this 0) #\}))
-	      (do ((i 0 (+ i 1)))
-		  ((or (>= i len)
-		       (not (char-whitespace? (string-ref this i))))
-		   (set! this (substring this i))))
-	      (when (and (> (length this) 0) (char=? (string-ref this 0) #\})
-			 (> (length last1) 0) (char=? (string-ref last1 0) #\}))
-		(format #f "~D ~S~%" line last1)))
-	    (set! last1 this)))))))
+  (lambda (p)
+    (let ((last1 "")
+	  (last-i 0))
+      (do ((this (read-line p) (read-line p))
+	   (line 0 (+ line 1)))
+	  ((eq? this #<eof>))
+	(let ((len (length this)))
+	  (unless (or (= len 0)
+		      (char=? (string-ref this 0) #\}))
+	    (do ((i 0 (+ i 1)))
+		((or (>= i len)
+		     (not (char-whitespace? (string-ref this i))))
+		 (when (and (< i len)
+			    (char=? (string-ref this i) #\})
+			    (> (length last1) 0)
+			    (char=? (string-ref last1 last-i) #\}))
+		   (format #f "~D ~S~%" line last1))
+		 (set! last-i i)
+		 (set! last1 this))))))))))
 
 
 ;;; --------------------------------
@@ -170,7 +175,7 @@
       (set! str str1)
       (cond2-cposrev-2 c1 0))))
 
-(define tc3-cpos ; eval? (there is no op_tc_if_a_z_if_a_z_l3a but the 2 case is slower -- 2 case is not s7_optimized)
+(define tc3-cpos ; eval? (there is no op_tc_if_a_z_if_a_z_l3a)
   (let ((len 0))
     (define (cpos-3 c str pos)
       (if (= pos len)
