@@ -416,11 +416,8 @@
   (load "fullmix.scm")		   
   (load "generators.scm")	   
   (load "grani.scm")		   
-					; (load "gtk-effects.scm")	   
   (load "snddiff.scm")
-					; (load "gtk-effects-utils.scm")  
 					; (load "snd-gl.scm")
-					; (load "snd-gtk.scm")
   (load "hooks.scm")		   
 					;(load "sndlib-ws.scm")
   (load "index.scm")		   
@@ -809,10 +806,7 @@
        (snd-effects-utils.scm "effects-utils.scm")
        (snd-fft-menu.scm "fft-menu.scm")
        (snd-fmv.scm "fmv.scm")
-       (snd-gtk-effects.scm "gtk-effects.scm")
-       (snd-gtk-effects-utils.scm "gtk-effects-utils.scm")
        (snd-snd-gl.scm "snd-gl.scm")
-       (snd-snd-gtk.scm "snd-gtk.scm")
        (snd-snd-motif.scm "snd-motif.scm")
        (snd-special-menu.scm "special-menu.scm")
        (snd-marks-menu.scm "marks-menu.scm")
