@@ -254,6 +254,9 @@
 (format *stderr* "~NC tmisc ~NC~%" 20 #\- 20 #\-)
 (system "./repl tmisc.scm")
 
+(format *stderr* "~NC tcase ~NC~%" 20 #\- 20 #\-)
+(system "./repl tcase.scm")
+
 (format *stderr* "~NC index ~NC~%" 20 #\- 20 #\-)
 (system "./snd make-index.scm")
 
