@@ -373,7 +373,7 @@
  	   (lambda (vi)
  	     (if (> vj vi) (display "oops"))
  	     (set! vj vi))
- 	   (subvector vs (- size 1) 1))))
+ 	   (subvector vs 1 size))))
       (byte-vector-checker)))
   
   (clear-and-gc)
@@ -407,7 +407,7 @@
 	(test (equivalent? big1 bigfv) #t)
 	(set! (big1 (- big-size 1)) 0.25)
 	(test (equivalent? big1 bigfv) #f)
-	(let ((big2 (subvector big1 20 (- (ash 1 31) 10))))
+	(let ((big2 (subvector big1 (- (ash 1 31) 10) (+ (ash 1 31) 10))))
 	  (test big2 (make-float-vector 20 0.5))
 	  (test (length big2) 20)
 	  (let ((big3 (make-float-vector 20 0.0)))
@@ -439,7 +439,7 @@
  	   (lambda (vi)
  	     (if (> vj vi) (display "oops"))
  	     (set! vj vi))
- 	   (subvector vs (- size 1) 1))))
+ 	   (subvector vs 1 size))))
       (float-vector-checker)))
   
   (clear-and-gc)
@@ -496,9 +496,12 @@
 	(set! (bigfv1 i) j)
 	(set! (bigfv2 i) (* (bigfv1 i) 2))))
     (f-loop)
-    (test (subvector bigfv1 20 (- (ash 1 32) 10)) (float-vector 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19))
-    (test (subvector bigfv2 20 (- (ash 1 32) 10)) (float-vector 0 2 4 6 8 10 12 14 16 18 20 22 24 26 28 30 32 34 36 38))
-    (test (subvector bigfv1 5 (+ (ash 1 32) 5)) (float-vector 15 16 17 18 19))))
+    (test (subvector bigfv1 (- (ash 1 32) 10) (+ (ash 1 32) 10))
+	  (float-vector 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19))
+    (test (subvector bigfv2 (- (ash 1 32) 10) (+ (ash 1 32) 10))
+	  (float-vector 0 2 4 6 8 10 12 14 16 18 20 22 24 26 28 30 32 34 36 38))
+    (test (subvector bigfv1 (+ (ash 1 32) 5) (+ (ash 1 32) 10))
+	  (float-vector 15 16 17 18 19))))
 
 (when (> total-memory (* 9 big-size))
   (format () "test 4~%")
@@ -751,7 +754,7 @@
 	(test (equivalent? big1 bigfv) #t)
 	(set! (big1 (- big-size 1)) 25)
 	(test (equivalent? big1 bigfv) #f)
-	(let ((big2 (subvector big1 20 (- (ash 1 31) 10))))
+	(let ((big2 (subvector big1 (- (ash 1 31) 10) (+ (ash 1 31) 10))))
 	  (test big2 (make-int-vector 20 5))
 	  (test (length big2) 20)
 	  (let ((big3 (make-int-vector 20 0)))
@@ -781,7 +784,7 @@
  	   (lambda (vi)
  	     (if (> vj vi) (display "oops"))
  	     (set! vj vi))
- 	   (subvector vs (- size 1) 1))))
+ 	   (subvector vs 1 size))))
       (int-vector-checker)))
   (sort! '(1 2 3) <) ; clear temp3...
   (clear-and-gc)
@@ -1090,8 +1093,8 @@
 	  (pw (/ n 2))
 	  (end 0)
 	  (theta (* pi dir))
-	  (rl0 (subvector rl fft-size))
-	  (rl1 (subvector rl fft-size fft-size)))
+	  (rl0 (subvector rl 0 fft-size))
+	  (rl1 (subvector rl fft-size (* 2 fft-size))))
       (do ((i 0 (+ i 1)))
 	  ((= i n))
 	(when (> j i)
@@ -1802,7 +1805,7 @@
   `(make-vector (make-list (+ 1 (random 4)) (+ 1 (random 4))) ,val))
 
 (define-expansion (old-value ref)
-  `((subvector ,ref 1) 0))
+  `((subvector ,ref 0 1) 0))
 
 (define (complex-2d-fft data n dir)
   (when data
