@@ -264,4 +264,6 @@
 ;(test-append 10000)
 |#
 
+(when (> (*s7* 'profile) 0)
+  (show-profile 200))
 (exit)
