@@ -150,4 +150,6 @@
  
 (fft-bench)
 
+(when (> (*s7* 'profile) 0)
+  (show-profile 200))
 (exit)
