@@ -97,4 +97,6 @@
   
   (test)
 
+  (when (> (*s7* 'profile) 0)
+    (show-profile 200))
   (exit))
