@@ -14,19 +14,20 @@
 	    (format *stderr* "y: ~A~%" y))))))
 (f2)
 
-#|
+
 (define (f2d)
   (let ((x 2)
-	(y 0))
+	(y 0)
+	(size2 50000))
     (do ((j 0 (+ j 1)))
 	((= j 1))
       (do ((i 0 (+ i 1)))
-	  ((= i size))
+	  ((= i size2))
 	(set! y ((macro (a b) `(+ ,a ,@b 1)) x (x x)))
 	(if (not (= y (+ (* 3 x) 1)))
 	    (format *stderr* "y: ~A~%" y))))))
 (f2d)
-|#
+
 
 (define-expansion (m3 a b) `(+ ,a ,@b 1))
 (define (f3)
