@@ -1,6 +1,6 @@
 ;;; sequence tests
 
-;(set! (*s7* 'heap-size) (* 4 1024000))
+(set! (*s7* 'heap-size) (* 3 1024000))
 
 (define (less-than a b)
   (or (< a b) (> b a)))
