@@ -16,13 +16,14 @@
 	    (set! phase (+ phase freq))))
 	;; now take the DFT
 	(let ((pk 0.0)
-	      (w (make-vector N)))
+	      (w (make-vector N))
+	      (c (* 2.0 0+1.0i pi)))
 	  (do ((i 0 (+ i 1))
 	       (sum 0.0 0.0))
 	      ((= i N))
 	    (do ((k 0 (+ k 1)))
 		((= k N))
-	      (set! sum (+ sum (* (vals k) (exp (/ (* 2.0 0+1.0i pi k i) N))))))
+	      (set! sum (+ sum (* (vals k) (exp (/ (* c k i) N))))))
 	    (set! (w i) (magnitude sum))
 	    (set! pk (max pk (w i))))
 	  ;; scale to 1.0 (it's usually pretty close already, that is pk is close to 1.0)
