@@ -52,4 +52,6 @@
 
 (t)
 
+(when (> (*s7* 'profile) 0)
+  (show-profile 200))
 (exit)
