@@ -89,14 +89,14 @@ return help associated with name (String or Symbol) or false"
 void xen_initialize(void)
 {
   int argc = 4;
-  char *argv[] = {"xen", "--disable-gems", "-e", ";"};
+  const char *argv[] = {"xen", "--disable-gems", "-e", ";"};
 
 #ifdef RUBY_INIT_STACK
   RUBY_INIT_STACK;
 #endif
 
   ruby_init();
-  ruby_options(argc, argv);
+  ruby_options(argc, (char **)argv);
   Init_Hook();
 }
 
